@@ -1,24 +1,24 @@
 getN <- function(model, what="CAc", series=NULL, digits=NULL)
 {
   ## 1  Parse args
-  if(class(model) != "scape")
-    stop("The 'model' argument should be a scape object, not ", class(model))
   what <- match.arg(what, c("CAc","CAs","CLc","CLs"))
-  x <- model[[what]]
+  x <- if(class(model)=="scape") model[[what]] else model  # allow data frame
   if(is.null(x))
-    stop("Element '", what, "' not found")
+    stop("element '", what, "' not found")
 
   ## 2  Extract series
   if(is.null(series))
     series <- unique(x$Series)
   if(length(series) > 1)
   {
-    output <- lapply(series, function(s) getN(model=model, what=what, series=s, digits=digits))
+    output <- lapply(series, function(s)
+                     getN(model=model, what=what, series=s, digits=digits))
     names(output) <- series
   }
   else
   {
-    ok.series <- x$Series %in% series; if(!any(ok.series)) stop("Please check if the 'series' argument is correct")
+    ok.series <- x$Series %in% series
+    if(!any(ok.series)) stop("please check if the 'series' argument is correct")
     x <- x[!is.na(x$Obs) & ok.series,]
 
     ## 3  Create output
@@ -28,5 +28,5 @@ getN <- function(model, what="CAc", series=NULL, digits=NULL)
       output <- round(output, digits=digits)
   }
 
-  return(output)
+  output
 }
