@@ -1,13 +1,14 @@
 getSigmaR <- function(model, digits=NULL)
 {
   ## 1  Parse args
-  if(class(model) != "scape")
-    stop("The 'model' argument should be a scape object, not ", class(model))
+  x <- if(class(model)=="scape") model$Dev else model  # allow data frame
+  if(is.null(x))
+    stop("element 'Dev' not found")
 
   ## 2  Create output
-  output <- model$Dev$sigmaR
+  output <- x$sigmaR
   if(!is.null(digits))
     output <- round(output, digits=digits)
 
-  return(output)
+  output
 }
