@@ -157,28 +157,26 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     17172.8, 4341.67, 6363.81, 4980.01, 310215, 71812.9, 229330, 
     137941, 89063.6, 46737, 5425.48, 8832.03, 2232.93, 5834.17, 
     378867, 253943, 58587.1, 181008, 94794.7, 49886.8, 25646.8, 
-    2977.22, 4846.56, 4426.82)), .Names = c("Sex", "Year", "Age", 
-"N"), row.names = c(NA, -340L), class = "data.frame"), B = structure(list(
-    Year = 1971:2004, VB = c(1140000, 964964, 761019, 722716, 
-    778435, 825133, 1050000, 1270000, 1330000, 1410000, 1190000, 
-    940285, 775779, 780698, 827749, 769197, 776460, 868580, 953567, 
-    784715, 610520, 495860, 470127, 468598, 518647, 577960, 682386, 
-    708012, 646309, 550857, 525343, 561627, 636831, 734505), 
-    SB = c(1370000, 1170000, 894552, 999547, 966587, 1060000, 
-    1480000, 1500000, 1630000, 1750000, 1410000, 1130000, 918667, 
-    1e+06, 1020000, 900452, 1090000, 1190000, 1200000, 912646, 
-    762816, 598591, 630708, 642020, 613469, 737990, 906160, 828555, 
-    817466, 623002, 700825, 737061, 808611, 982954), Y = c(453052, 
-    398528, 383446, 374770, 370991, 347849, 340050, 330390, 368064, 
-    434344, 468659, 388387, 300056, 283822, 325267, 368633, 392257, 
-    378076, 355954, 335390, 308560, 267767, 251979, 178809, 169424, 
-    181658, 203153, 242632, 260052, 235654, 235098, 208830, 210000, 
-    NA), R = c(262806, 425777, 628953, 207659, 360187, 401021, 
-    229905, 234366, 186469, 328677, 213028, 185820, 530062, 510445, 
-    277039, 117558, 192850, 146381, 260156, 232307, 103293, 242279, 
-    301904, 112824, 226670, 66566.4, 265870, 255701, 263285, 
-    343564, 87727.6, 310215, 378867, NA)), .Names = c("Year", 
-"VB", "SB", "Y", "R"), row.names = c(NA, -34L), class = "data.frame"), 
+    2977.22, 4846.56, 4426.82)), class = "data.frame", row.names = c(NA, 
+-340L)), B = structure(list(Year = 1971:2004, VB = c(1140000, 
+964964, 761019, 722716, 778435, 825133, 1050000, 1270000, 1330000, 
+1410000, 1190000, 940285, 775779, 780698, 827749, 769197, 776460, 
+868580, 953567, 784715, 610520, 495860, 470127, 468598, 518647, 
+577960, 682386, 708012, 646309, 550857, 525343, 561627, 636831, 
+734505), SB = c(1370000, 1170000, 894552, 999547, 966587, 1060000, 
+1480000, 1500000, 1630000, 1750000, 1410000, 1130000, 918667, 
+1e+06, 1020000, 900452, 1090000, 1190000, 1200000, 912646, 762816, 
+598591, 630708, 642020, 613469, 737990, 906160, 828555, 817466, 
+623002, 700825, 737061, 808611, 982954), Y = c(453052, 398528, 
+383446, 374770, 370991, 347849, 340050, 330390, 368064, 434344, 
+468659, 388387, 300056, 283822, 325267, 368633, 392257, 378076, 
+355954, 335390, 308560, 267767, 251979, 178809, 169424, 181658, 
+203153, 242632, 260052, 235654, 235098, 208830, 210000, NA), 
+    R = c(262806, 425777, 628953, 207659, 360187, 401021, 229905, 
+    234366, 186469, 328677, 213028, 185820, 530062, 510445, 277039, 
+    117558, 192850, 146381, 260156, 232307, 103293, 242279, 301904, 
+    112824, 226670, 66566.4, 265870, 255701, 263285, 343564, 
+    87727.6, 310215, 378867, NA)), row.names = c(NA, -34L), class = "data.frame"), 
     Sel = structure(list(Series = c("Gear 1", "Gear 1", "Gear 1", 
     "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
     "Gear 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
@@ -196,24 +194,22 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     0.0107437, 0.109044, 0.487138, 0.957858, 1, 0.999999, 0.999998, 
     0.999996, 0.999993, 0.093353, 0.30199, 0.656636, 0.959678, 
     1, 0.999999, 0.999998, 0.999996, 0.999994, 0.999991, 0, 0, 
-    0, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", "Sex", "Age", 
-    "P"), row.names = c(NA, -30L), class = "data.frame"), Dev = structure(list(
-        sigmaR = structure(c(0.5, 1), .Names = c("Initial", "Annual"
-        )), Initial = structure(c(-0.276004, -0.133551, -0.08248, 
-        0.0879693, -0.161992, 0.19093, 0.323306, 0.082165), .Names = c("2", 
-        "3", "4", "5", "6", "7", "8", "9")), Annual = structure(c(0.904468, 
-        0.0370796, 0.544025, 0.98496, -0.145333, 0.411873, 0.501718, 
-        -0.107777, -0.0903785, -0.329944, 0.228531, -0.176938, 
-        -0.278815, 0.808412, 0.753572, 0.138847, -0.693534, -0.235523, 
-        -0.526445, 0.0482014, -0.0151754, -0.786165, 0.129073, 
-        0.334609, -0.654477, 0.0556041, -1.21763, 0.121238, 0.101377, 
-        0.133603, 0.467231, -0.928844, 0.321739), .Names = c("1971", 
-        "1972", "1973", "1974", "1975", "1976", "1977", "1978", 
-        "1979", "1980", "1981", "1982", "1983", "1984", "1985", 
-        "1986", "1987", "1988", "1989", "1990", "1991", "1992", 
-        "1993", "1994", "1995", "1996", "1997", "1998", "1999", 
-        "2000", "2001", "2002", "2003"))), .Names = c("sigmaR", 
-    "Initial", "Annual")), Survey = structure(list(Series = c(1L, 
+    0, 1, 1, 1, 1, 1, 1, 1)), class = "data.frame", row.names = c(NA, 
+    -30L)), Dev = list(sigmaR = c(Initial = 0.5, Annual = 1), 
+        Initial = c(`2` = -0.276004, `3` = -0.133551, `4` = -0.08248, 
+        `5` = 0.0879693, `6` = -0.161992, `7` = 0.19093, `8` = 0.323306, 
+        `9` = 0.082165), Annual = c(`1971` = 0.904468, `1972` = 0.0370796, 
+        `1973` = 0.544025, `1974` = 0.98496, `1975` = -0.145333, 
+        `1976` = 0.411873, `1977` = 0.501718, `1978` = -0.107777, 
+        `1979` = -0.0903785, `1980` = -0.329944, `1981` = 0.228531, 
+        `1982` = -0.176938, `1983` = -0.278815, `1984` = 0.808412, 
+        `1985` = 0.753572, `1986` = 0.138847, `1987` = -0.693534, 
+        `1988` = -0.235523, `1989` = -0.526445, `1990` = 0.0482014, 
+        `1991` = -0.0151754, `1992` = -0.786165, `1993` = 0.129073, 
+        `1994` = 0.334609, `1995` = -0.654477, `1996` = 0.0556041, 
+        `1997` = -1.21763, `1998` = 0.121238, `1999` = 0.101377, 
+        `2000` = 0.133603, `2001` = 0.467231, `2002` = -0.928844, 
+        `2003` = 0.321739)), Survey = structure(list(Series = c(1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L), Year = 1971:2004, Obs = c(NA, NA, NA, NA, NA, 
@@ -227,9 +223,8 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     638.789, 519.153, 410.725, 364.678, 378.4, 384.105, 419.75, 
     464.846, 459.498, 424.87, 346.746, 285.949, 252.182, 259.693, 
     237.64, 256.392, 313.859, 329.732, 322.584, 288.12, 263.397, 
-    292.159, 298.522, 342.267, 348.371)), .Names = c("Series", 
-    "Year", "Obs", "CV", "Fit"), row.names = c(NA, -34L), class = "data.frame"), 
-    CAc = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
+    292.159, 298.522, 342.267, 348.371)), row.names = c(NA, -34L
+    ), class = "data.frame"), CAc = structure(list(Series = c(1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
@@ -250,43 +245,44 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
-    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = c(1971L, 
-    1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 
-    1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 
-    1972L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 
-    1973L, 1973L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 
-    1974L, 1974L, 1974L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 
-    1975L, 1975L, 1975L, 1975L, 1976L, 1976L, 1976L, 1976L, 1976L, 
-    1976L, 1976L, 1976L, 1976L, 1976L, 1977L, 1977L, 1977L, 1977L, 
-    1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1978L, 1978L, 1978L, 
-    1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1979L, 1979L, 
-    1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1980L, 
-    1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 
-    1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 
-    1981L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 
-    1982L, 1982L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 
-    1983L, 1983L, 1983L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 
-    1984L, 1984L, 1984L, 1984L, 1985L, 1985L, 1985L, 1985L, 1985L, 
-    1985L, 1985L, 1985L, 1985L, 1985L, 1986L, 1986L, 1986L, 1986L, 
-    1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1987L, 1987L, 1987L, 
-    1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1988L, 1988L, 
-    1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1989L, 
-    1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 
-    1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 
-    1990L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 
-    1991L, 1991L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 
-    1992L, 1992L, 1992L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 
-    1993L, 1993L, 1993L, 1993L, 1994L, 1994L, 1994L, 1994L, 1994L, 
-    1994L, 1994L, 1994L, 1994L, 1994L, 1995L, 1995L, 1995L, 1995L, 
-    1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1996L, 1996L, 1996L, 
-    1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1997L, 1997L, 
-    1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1998L, 
-    1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 
-    1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 
-    1999L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 
-    2000L, 2000L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 
-    2001L, 2001L, 2001L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 
-    2002L, 2002L, 2002L, 2002L), SS = c(50, 50, 50, 50, 50, 50, 
+    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
+    1L, 1L, 1L, 1L), Year = c(1971L, 1971L, 1971L, 1971L, 1971L, 
+    1971L, 1971L, 1971L, 1971L, 1971L, 1972L, 1972L, 1972L, 1972L, 
+    1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1973L, 1973L, 1973L, 
+    1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1974L, 1974L, 
+    1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1975L, 
+    1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 
+    1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 
+    1976L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 
+    1977L, 1977L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 
+    1978L, 1978L, 1978L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 
+    1979L, 1979L, 1979L, 1979L, 1980L, 1980L, 1980L, 1980L, 1980L, 
+    1980L, 1980L, 1980L, 1980L, 1980L, 1981L, 1981L, 1981L, 1981L, 
+    1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1982L, 1982L, 1982L, 
+    1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1983L, 1983L, 
+    1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1984L, 
+    1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 
+    1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 
+    1985L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 
+    1986L, 1986L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 
+    1987L, 1987L, 1987L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 
+    1988L, 1988L, 1988L, 1988L, 1989L, 1989L, 1989L, 1989L, 1989L, 
+    1989L, 1989L, 1989L, 1989L, 1989L, 1990L, 1990L, 1990L, 1990L, 
+    1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1991L, 1991L, 1991L, 
+    1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1992L, 1992L, 
+    1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1993L, 
+    1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 
+    1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 
+    1994L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 
+    1995L, 1995L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 
+    1996L, 1996L, 1996L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 
+    1997L, 1997L, 1997L, 1997L, 1998L, 1998L, 1998L, 1998L, 1998L, 
+    1998L, 1998L, 1998L, 1998L, 1998L, 1999L, 1999L, 1999L, 1999L, 
+    1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 2000L, 2000L, 2000L, 
+    2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2001L, 2001L, 
+    2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2002L, 
+    2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L
+    ), SS = c(50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
@@ -307,139 +303,137 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
     50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
-    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50), 
-        Sex = c("Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 3L, 4L, 
-        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
-        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
-        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
-        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
-        7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
-        10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
-        3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
-        6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
-        9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
-        2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
-        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
-        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
-        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
-        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
-        7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
-        10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
-        3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
-        6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
-        9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
-        2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
-        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
-        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
-        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
-        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
-        7L, 8L, 9L, 10L), Obs = c(0, 0, 0.0845488, 0.232127, 
-        0.29506, 0.136825, 0.112257, 0.0707206, 0.0388497, 0.0296115, 
-        0, 0, 0.0695204, 0.229131, 0.239544, 0.177074, 0.0859766, 
-        0.0758038, 0.0816456, 0.0413032, 0, 0, 0.270907, 0.189378, 
-        0.203087, 0.126378, 0.0943184, 0.027322, 0.0349811, 0.0536282, 
-        0, 0, 0.110408, 0.459793, 0.162302, 0.107188, 0.0667386, 
-        0.0462276, 0.0122485, 0.0350946, 0, 0, 0.221055, 0.222473, 
-        0.332989, 0.0911951, 0.0726362, 0.0278459, 0.0154733, 
-        0.0163333, 0, 0, 0.192654, 0.325122, 0.172341, 0.19933, 
-        0.0474159, 0.0436573, 0.0105977, 0.00888181, 0, 0, 0.0241952, 
-        0.394852, 0.300496, 0.112572, 0.120485, 0.0260001, 0.0164109, 
-        0.00498898, 0, 0, 0.0610734, 0.165811, 0.447244, 0.179443, 
-        0.0888665, 0.0419339, 0.00995663, 0.0056706, 0, 0, 0.0688281, 
-        0.272276, 0.131909, 0.329898, 0.135338, 0.0423926, 0.0137158, 
-        0.00564149, 0, 0, 0.0366357, 0.24039, 0.273841, 0.127391, 
-        0.228257, 0.0661179, 0.0187729, 0.00859439, 0, 0, 0.0170211, 
-        0.10686, 0.314986, 0.186822, 0.102143, 0.212603, 0.0386068, 
-        0.0209589, 0, 0, 0.0292021, 0.185009, 0.217455, 0.252027, 
-        0.12456, 0.0681471, 0.102381, 0.0212193, 0, 0, 0.0398909, 
-        0.122456, 0.272805, 0.212632, 0.1951, 0.0940702, 0.0230546, 
-        0.0399919, 0, 0, 0.0729588, 0.341047, 0.209905, 0.165654, 
-        0.087356, 0.0792927, 0.0289673, 0.0148187, 0, 0, 0.0636176, 
-        0.241899, 0.3487, 0.179976, 0.0858252, 0.0413904, 0.0223061, 
-        0.0162862, 0, 0, 0.175677, 0.173021, 0.226757, 0.26246, 
-        0.0971319, 0.0377957, 0.0150723, 0.0120851, 0, 0, 0.0798062, 
-        0.450678, 0.197245, 0.109728, 0.113848, 0.0301685, 0.0106123, 
-        0.00791388, 0, 0, 0.0496263, 0.290698, 0.413208, 0.137967, 
-        0.047305, 0.0434461, 0.009943, 0.00780655, 0, 0, 0.0214635, 
-        0.230561, 0.412453, 0.259168, 0.0495184, 0.0157783, 0.00725885, 
-        0.00379833, 0, 0, 0.0523269, 0.111374, 0.245841, 0.402822, 
-        0.154104, 0.0232735, 0.00550857, 0.00474877, 0, 0, 0.0826881, 
-        0.242931, 0.149745, 0.207967, 0.242032, 0.0615182, 0.00872894, 
-        0.00438864, 0, 0, 0.131937, 0.234435, 0.286446, 0.123255, 
-        0.108783, 0.0896789, 0.0216638, 0.00380142, 0, 0, 0.221507, 
-        0.357415, 0.164185, 0.143504, 0.038715, 0.0300925, 0.0292497, 
-        0.0153326, 0, 0, 0.0961764, 0.37693, 0.307046, 0.108792, 
-        0.0685881, 0.0196256, 0.00935222, 0.0134897, 0, 0, 0.191263, 
-        0.161659, 0.298863, 0.232037, 0.0730776, 0.0283431, 0.00555852, 
-        0.00919908, 0, 0, 0.10153, 0.282183, 0.139746, 0.233295, 
-        0.178739, 0.0408887, 0.0158664, 0.00775311, 0, 0, 0.0300199, 
-        0.286636, 0.301559, 0.116994, 0.128639, 0.103867, 0.0199958, 
-        0.0122904, 0, 0, 0.0492431, 0.10975, 0.361619, 0.287185, 
-        0.0839184, 0.0549108, 0.0420233, 0.0113496, 0, 0, 0.0315137, 
-        0.244047, 0.19003, 0.307299, 0.161824, 0.0348834, 0.0185587, 
-        0.0118441, 0, 0, 0.137208, 0.0860543, 0.380255, 0.146806, 
-        0.148938, 0.0734488, 0.0144361, 0.0128539, 0, 0, 0.146257, 
-        0.323012, 0.120108, 0.251174, 0.0724961, 0.050684, 0.0260196, 
-        0.0102478, 0, 0, 0.0855117, 0.266334, 0.350131, 0.0990576, 
-        0.128873, 0.0320921, 0.0194974, 0.018503), Fit = c(0.000638965, 
-        0.00539005, 0.0514821, 0.19173, 0.312928, 0.148901, 0.12184, 
-        0.0799654, 0.036124, 0.0509998, 0.000409886, 0.0139091, 
-        0.051432, 0.207722, 0.286914, 0.190819, 0.0846123, 0.0692351, 
-        0.0454399, 0.0495077, 0.000714247, 0.00832158, 0.123764, 
-        0.193218, 0.287313, 0.159426, 0.0986369, 0.0437373, 0.0357886, 
+    50, 50, 50, 50, 50, 50, 50, 50), Sex = c("Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex"
+    ), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
+    7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
+    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
+    5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
+    9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
+    7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
+    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
+    5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
+    9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
+    7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
+    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
+    5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
+    9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
+    7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
+    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
+    5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
+    9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
+    7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L), 
+        Obs = c(0, 0, 0.0845488, 0.232127, 0.29506, 0.136825, 
+        0.112257, 0.0707206, 0.0388497, 0.0296115, 0, 0, 0.0695204, 
+        0.229131, 0.239544, 0.177074, 0.0859766, 0.0758038, 0.0816456, 
+        0.0413032, 0, 0, 0.270907, 0.189378, 0.203087, 0.126378, 
+        0.0943184, 0.027322, 0.0349811, 0.0536282, 0, 0, 0.110408, 
+        0.459793, 0.162302, 0.107188, 0.0667386, 0.0462276, 0.0122485, 
+        0.0350946, 0, 0, 0.221055, 0.222473, 0.332989, 0.0911951, 
+        0.0726362, 0.0278459, 0.0154733, 0.0163333, 0, 0, 0.192654, 
+        0.325122, 0.172341, 0.19933, 0.0474159, 0.0436573, 0.0105977, 
+        0.00888181, 0, 0, 0.0241952, 0.394852, 0.300496, 0.112572, 
+        0.120485, 0.0260001, 0.0164109, 0.00498898, 0, 0, 0.0610734, 
+        0.165811, 0.447244, 0.179443, 0.0888665, 0.0419339, 0.00995663, 
+        0.0056706, 0, 0, 0.0688281, 0.272276, 0.131909, 0.329898, 
+        0.135338, 0.0423926, 0.0137158, 0.00564149, 0, 0, 0.0366357, 
+        0.24039, 0.273841, 0.127391, 0.228257, 0.0661179, 0.0187729, 
+        0.00859439, 0, 0, 0.0170211, 0.10686, 0.314986, 0.186822, 
+        0.102143, 0.212603, 0.0386068, 0.0209589, 0, 0, 0.0292021, 
+        0.185009, 0.217455, 0.252027, 0.12456, 0.0681471, 0.102381, 
+        0.0212193, 0, 0, 0.0398909, 0.122456, 0.272805, 0.212632, 
+        0.1951, 0.0940702, 0.0230546, 0.0399919, 0, 0, 0.0729588, 
+        0.341047, 0.209905, 0.165654, 0.087356, 0.0792927, 0.0289673, 
+        0.0148187, 0, 0, 0.0636176, 0.241899, 0.3487, 0.179976, 
+        0.0858252, 0.0413904, 0.0223061, 0.0162862, 0, 0, 0.175677, 
+        0.173021, 0.226757, 0.26246, 0.0971319, 0.0377957, 0.0150723, 
+        0.0120851, 0, 0, 0.0798062, 0.450678, 0.197245, 0.109728, 
+        0.113848, 0.0301685, 0.0106123, 0.00791388, 0, 0, 0.0496263, 
+        0.290698, 0.413208, 0.137967, 0.047305, 0.0434461, 0.009943, 
+        0.00780655, 0, 0, 0.0214635, 0.230561, 0.412453, 0.259168, 
+        0.0495184, 0.0157783, 0.00725885, 0.00379833, 0, 0, 0.0523269, 
+        0.111374, 0.245841, 0.402822, 0.154104, 0.0232735, 0.00550857, 
+        0.00474877, 0, 0, 0.0826881, 0.242931, 0.149745, 0.207967, 
+        0.242032, 0.0615182, 0.00872894, 0.00438864, 0, 0, 0.131937, 
+        0.234435, 0.286446, 0.123255, 0.108783, 0.0896789, 0.0216638, 
+        0.00380142, 0, 0, 0.221507, 0.357415, 0.164185, 0.143504, 
+        0.038715, 0.0300925, 0.0292497, 0.0153326, 0, 0, 0.0961764, 
+        0.37693, 0.307046, 0.108792, 0.0685881, 0.0196256, 0.00935222, 
+        0.0134897, 0, 0, 0.191263, 0.161659, 0.298863, 0.232037, 
+        0.0730776, 0.0283431, 0.00555852, 0.00919908, 0, 0, 0.10153, 
+        0.282183, 0.139746, 0.233295, 0.178739, 0.0408887, 0.0158664, 
+        0.00775311, 0, 0, 0.0300199, 0.286636, 0.301559, 0.116994, 
+        0.128639, 0.103867, 0.0199958, 0.0122904, 0, 0, 0.0492431, 
+        0.10975, 0.361619, 0.287185, 0.0839184, 0.0549108, 0.0420233, 
+        0.0113496, 0, 0, 0.0315137, 0.244047, 0.19003, 0.307299, 
+        0.161824, 0.0348834, 0.0185587, 0.0118441, 0, 0, 0.137208, 
+        0.0860543, 0.380255, 0.146806, 0.148938, 0.0734488, 0.0144361, 
+        0.0128539, 0, 0, 0.146257, 0.323012, 0.120108, 0.251174, 
+        0.0724961, 0.050684, 0.0260196, 0.0102478, 0, 0, 0.0855117, 
+        0.266334, 0.350131, 0.0990576, 0.128873, 0.0320921, 0.0194974, 
+        0.018503), Fit = c(0.000638965, 0.00539005, 0.0514821, 
+        0.19173, 0.312928, 0.148901, 0.12184, 0.0799654, 0.036124, 
+        0.0509998, 0.000409886, 0.0139091, 0.051432, 0.207722, 
+        0.286914, 0.190819, 0.0846123, 0.0692351, 0.0454399, 
+        0.0495077, 0.000714247, 0.00832158, 0.123764, 0.193218, 
+        0.287313, 0.159426, 0.0986369, 0.0437373, 0.0357886, 
         0.04908, 0.0010244, 0.0130894, 0.0667764, 0.415362, 0.227884, 
         0.123364, 0.0628768, 0.0389019, 0.0172498, 0.0334719, 
         0.00031764, 0.0181587, 0.101581, 0.216404, 0.46935, 0.0920679, 
@@ -494,8 +488,7 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         0.0126681, 0.101768, 0.36908, 0.118183, 0.207708, 0.0525131, 
         0.0769709, 0.0349672, 0.0252663, 0.000189883, 0.0140363, 
         0.0889552, 0.300633, 0.394533, 0.0490072, 0.0797777, 
-        0.0201695, 0.0295635, 0.0231349)), .Names = c("Series", 
-    "Year", "SS", "Sex", "Age", "Obs", "Fit"), row.names = c(NA, 
+        0.0201695, 0.0295635, 0.0231349)), row.names = c(NA, 
     -320L), class = "data.frame"), CAs = structure(list(Series = c(1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
@@ -662,7 +655,5 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         0.24639, 0.272421, 0.189458, 0.0225419, 0.0366954, 0.00927738, 
         0.0135983, 0.0106413, 0.0588922, 0.0441024, 0.306234, 
         0.269207, 0.18112, 0.0950447, 0.0110333, 0.0179608, 0.00454088, 
-        0.0118643)), .Names = c("Series", "Year", "SS", "Sex", 
-    "Age", "Obs", "Fit"), row.names = c(NA, -190L), class = "data.frame")), .Names = c("N", 
-"B", "Sel", "Dev", "Survey", "CAc", "CAs"), call = quote(importCol(res.file = "c:/scape/example/cod.res", 
-    Dev = TRUE, Survey = TRUE, CAc = TRUE, CAs = TRUE)), scape.version = "2.0-2", info = "", class = "scape")
+        0.0118643)), row.names = c(NA, -190L), class = "data.frame")), call = quote(importCol(res.file = "~/r/library/scape/example/cod.res", 
+    Dev = TRUE, Survey = TRUE, CAc = TRUE, CAs = TRUE)), class = "scape")
